@@ -1,15 +1,16 @@
 """
 Type annotations for ec2-instance-connect service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/)
 
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_ec2_instance_connect import EC2InstanceConnectClient
+    from boto3.session import Session
+    from mypy_boto3_ec2_instance_connect.client import EC2InstanceConnectClient
 
-    client: EC2InstanceConnectClient = boto3.client("ec2-instance-connect")
+    session = Session()
+    client: EC2InstanceConnectClient = session.client("ec2-instance-connect")
     ```
 """
 from typing import Any, Dict, Mapping, Type
@@ -44,8 +45,8 @@ class Exceptions:
 
 class EC2InstanceConnectClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/)
     """
 
     meta: ClientMeta
@@ -54,14 +55,17 @@ class EC2InstanceConnectClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         EC2InstanceConnectClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/#can_paginate)
         """
 
     def generate_presigned_url(
@@ -74,8 +78,8 @@ class EC2InstanceConnectClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/#generate_presigned_url)
         """
 
     def send_serial_console_ssh_public_key(
@@ -84,8 +88,8 @@ class EC2InstanceConnectClient(BaseClient):
         """
         Pushes an SSH public key to the specified EC2 instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_serial_console_ssh_public_key)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#send_serial_console_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_serial_console_ssh_public_key)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/#send_serial_console_ssh_public_key)
         """
 
     def send_ssh_public_key(
@@ -95,6 +99,6 @@ class EC2InstanceConnectClient(BaseClient):
         Pushes an SSH public key to the specified EC2 instance for use by the specified
         user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.11/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client.html#send_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/#send_ssh_public_key)
         """
