@@ -1,14 +1,14 @@
 """
 Type annotations for ec2-instance-connect service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/literals/)
 
 Usage::
 
     ```python
-    from mypy_boto3_ec2_instance_connect.literals import ServiceName
+    from mypy_boto3_ec2_instance_connect.literals import EC2InstanceConnectServiceName
 
-    data: ServiceName = "accessanalyzer"
+    data: EC2InstanceConnectServiceName = "ec2-instance-connect"
     ```
 """
 import sys
@@ -19,9 +19,10 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ServiceName",)
+__all__ = ("EC2InstanceConnectServiceName", "ServiceName", "ResourceServiceName")
 
 
+EC2InstanceConnectServiceName = Literal["ec2-instance-connect"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -310,3 +311,15 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
