@@ -1,7 +1,7 @@
 """
 Type annotations for ec2-instance-connect service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/type_defs/)
 
 Usage::
 
@@ -12,7 +12,9 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict
+from typing import Dict
+
+from typing_extensions import NotRequired
 
 if sys.version_info >= (3, 9):
     from typing import TypedDict
@@ -34,7 +36,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
